Skip to contents

The jamba package contains several jam base functions which are re-usable for routine R analysis work, and are important dependencies for other Jam R packages.

Details

See the function reference for a complete list of functions.

The goal is to implement methods as lightweight as possible, so so inclusion in an analysis workflow will not incur a noticeable burden.

plot functions

string functions

color functions

miscellaneous helper functions

export and import functions

Jam options

The jamba package recognizes some global options, but limits these options to include only non-analysis options. For example, no global option should change the numerical manipulation of data.

  • jam.lightMode - logical whether the R console or graphical background is light or dark, printDebug() limits the luminance range to maximize visual contrast.

  • jam.Crange,jam.Lrange - numerical values used by printDebug() to maximize visual contrast, used with jam.lightMode.

  • jam.shadowColor,jam.shadow.r,jam.shadow.n,jam.alphaShadow, jam.outline,jam.alphaOutline to customize details for shadowText(), see shadowText_options() for convenience.

Author

Maintainer: James M. Ward jmw86069@gmail.com (ORCID) [copyright holder]

Authors: